Class: Aws::SavingsPlans::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SavingsPlans::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-savingsplans/client.rb,
sig/client.rbs
Overview
An API client for SavingsPlans. To construct a client, you need to configure a :region and :credentials.
client = Aws::SavingsPlans::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateSavingsPlanResponseSuccess, _DeleteQueuedSavingsPlanResponseSuccess, _DescribeSavingsPlanRatesResponseSuccess, _DescribeSavingsPlansOfferingRatesResponseSuccess, _DescribeSavingsPlansOfferingsResponseSuccess, _DescribeSavingsPlansResponseSuccess, _ListTagsForResourceResponseSuccess, _ReturnSavingsPlanResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_savings_plan(params = {}) ⇒ Types::CreateSavingsPlanResponse
Creates a Savings Plan.
-
#delete_queued_savings_plan(params = {}) ⇒ Struct
Deletes the queued purchase for the specified Savings Plan.
-
#describe_savings_plan_rates(params = {}) ⇒ Types::DescribeSavingsPlanRatesResponse
Describes the rates for a specific, existing Savings Plan.
-
#describe_savings_plans(params = {}) ⇒ Types::DescribeSavingsPlansResponse
Describes the specified Savings Plans.
-
#describe_savings_plans_offering_rates(params = {}) ⇒ Types::DescribeSavingsPlansOfferingRatesResponse
Describes the offering rates for Savings Plans you might want to purchase.
-
#describe_savings_plans_offerings(params = {}) ⇒ Types::DescribeSavingsPlansOfferingsResponse
Describes the offerings for the specified Savings Plans.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
-
#return_savings_plan(params = {}) ⇒ Types::ReturnSavingsPlanResponse
Returns the specified Savings Plan.
-
#tag_resource(params = {}) ⇒ Struct
Adds the specified tags to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the specified resource.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-savingsplans/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1038 1039 1040 |
# File 'lib/aws-sdk-savingsplans/client.rb', line 1038 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1041 1042 1043 |
# File 'lib/aws-sdk-savingsplans/client.rb', line 1041 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 |
# File 'lib/aws-sdk-savingsplans/client.rb', line 1011 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SavingsPlans') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-savingsplans' context[:gem_version] = '1.80.0' Seahorse::Client::Request.new(handlers, context) end |
#create_savings_plan(params = {}) ⇒ Types::CreateSavingsPlanResponse
Creates a Savings Plan.
86 |
# File 'sig/client.rbs', line 86
def create_savings_plan: (
|
#delete_queued_savings_plan(params = {}) ⇒ Struct
Deletes the queued purchase for the specified Savings Plan.
100 |
# File 'sig/client.rbs', line 100
def delete_queued_savings_plan: (
|
#describe_savings_plan_rates(params = {}) ⇒ Types::DescribeSavingsPlanRatesResponse
Describes the rates for a specific, existing Savings Plan.
112 |
# File 'sig/client.rbs', line 112
def describe_savings_plan_rates: (
|
#describe_savings_plans(params = {}) ⇒ Types::DescribeSavingsPlansResponse
Describes the specified Savings Plans.
131 |
# File 'sig/client.rbs', line 131
def describe_savings_plans: (
|
#describe_savings_plans_offering_rates(params = {}) ⇒ Types::DescribeSavingsPlansOfferingRatesResponse
Describes the offering rates for Savings Plans you might want to purchase.
152 |
# File 'sig/client.rbs', line 152
def describe_savings_plans_offering_rates: (
|
#describe_savings_plans_offerings(params = {}) ⇒ Types::DescribeSavingsPlansOfferingsResponse
Describes the offerings for the specified Savings Plans.
177 |
# File 'sig/client.rbs', line 177
def describe_savings_plans_offerings: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
204 |
# File 'sig/client.rbs', line 204
def list_tags_for_resource: (
|
#return_savings_plan(params = {}) ⇒ Types::ReturnSavingsPlanResponse
Returns the specified Savings Plan.
214 |
# File 'sig/client.rbs', line 214
def return_savings_plan: (
|
#tag_resource(params = {}) ⇒ Struct
Adds the specified tags to the specified resource.
224 |
# File 'sig/client.rbs', line 224
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the specified resource.
234 |
# File 'sig/client.rbs', line 234
def untag_resource: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1031 1032 1033 |
# File 'lib/aws-sdk-savingsplans/client.rb', line 1031 def waiter_names [] end |