Class: Aws::SavingsPlans::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SavingsPlans::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-savingsplans/client.rb
Overview
An API client for SavingsPlans. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::SavingsPlans::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_savings_plan(params = {}) ⇒ Types::CreateSavingsPlanResponse
Creates a Savings Plan.
-
#delete_queued_savings_plan(params = {}) ⇒ Struct
Deletes the queued purchase for the specified Savings Plan.
-
#describe_savings_plan_rates(params = {}) ⇒ Types::DescribeSavingsPlanRatesResponse
Describes the rates for a specific, existing Savings Plan.
-
#describe_savings_plans(params = {}) ⇒ Types::DescribeSavingsPlansResponse
Describes the specified Savings Plans.
-
#describe_savings_plans_offering_rates(params = {}) ⇒ Types::DescribeSavingsPlansOfferingRatesResponse
Describes the offering rates for Savings Plans you might want to purchase.
-
#describe_savings_plans_offerings(params = {}) ⇒ Types::DescribeSavingsPlansOfferingsResponse
Describes the offerings for the specified Savings Plans.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
-
#return_savings_plan(params = {}) ⇒ Types::ReturnSavingsPlanResponse
Returns the specified Savings Plan.
-
#tag_resource(params = {}) ⇒ Struct
Adds the specified tags to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the specified resource.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-savingsplans/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1038 1039 1040 |
# File 'lib/aws-sdk-savingsplans/client.rb', line 1038 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1041 1042 1043 |
# File 'lib/aws-sdk-savingsplans/client.rb', line 1041 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 |
# File 'lib/aws-sdk-savingsplans/client.rb', line 1011 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SavingsPlans') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-savingsplans' context[:gem_version] = '1.78.0' Seahorse::Client::Request.new(handlers, context) end |
#create_savings_plan(params = {}) ⇒ Types::CreateSavingsPlanResponse
Creates a Savings Plan.
531 532 533 534 |
# File 'lib/aws-sdk-savingsplans/client.rb', line 531 def create_savings_plan(params = {}, = {}) req = build_request(:create_savings_plan, params) req.send_request() end |
#delete_queued_savings_plan(params = {}) ⇒ Struct
Deletes the queued purchase for the specified Savings Plan.
553 554 555 556 |
# File 'lib/aws-sdk-savingsplans/client.rb', line 553 def delete_queued_savings_plan(params = {}, = {}) req = build_request(:delete_queued_savings_plan, params) req.send_request() end |
#describe_savings_plan_rates(params = {}) ⇒ Types::DescribeSavingsPlanRatesResponse
Describes the rates for a specific, existing Savings Plan.
614 615 616 617 |
# File 'lib/aws-sdk-savingsplans/client.rb', line 614 def describe_savings_plan_rates(params = {}, = {}) req = build_request(:describe_savings_plan_rates, params) req.send_request() end |
#describe_savings_plans(params = {}) ⇒ Types::DescribeSavingsPlansResponse
Describes the specified Savings Plans.
692 693 694 695 |
# File 'lib/aws-sdk-savingsplans/client.rb', line 692 def describe_savings_plans(params = {}, = {}) req = build_request(:describe_savings_plans, params) req.send_request() end |
#describe_savings_plans_offering_rates(params = {}) ⇒ Types::DescribeSavingsPlansOfferingRatesResponse
Describes the offering rates for Savings Plans you might want to purchase.
782 783 784 785 |
# File 'lib/aws-sdk-savingsplans/client.rb', line 782 def describe_savings_plans_offering_rates(params = {}, = {}) req = build_request(:describe_savings_plans_offering_rates, params) req.send_request() end |
#describe_savings_plans_offerings(params = {}) ⇒ Types::DescribeSavingsPlansOfferingsResponse
Describes the offerings for the specified Savings Plans.
882 883 884 885 |
# File 'lib/aws-sdk-savingsplans/client.rb', line 882 def describe_savings_plans_offerings(params = {}, = {}) req = build_request(:describe_savings_plans_offerings, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
911 912 913 914 |
# File 'lib/aws-sdk-savingsplans/client.rb', line 911 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#return_savings_plan(params = {}) ⇒ Types::ReturnSavingsPlanResponse
Returns the specified Savings Plan.
947 948 949 950 |
# File 'lib/aws-sdk-savingsplans/client.rb', line 947 def return_savings_plan(params = {}, = {}) req = build_request(:return_savings_plan, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds the specified tags to the specified resource.
976 977 978 979 |
# File 'lib/aws-sdk-savingsplans/client.rb', line 976 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the specified resource.
1002 1003 1004 1005 |
# File 'lib/aws-sdk-savingsplans/client.rb', line 1002 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1031 1032 1033 |
# File 'lib/aws-sdk-savingsplans/client.rb', line 1031 def waiter_names [] end |