Class: Aws::SavingsPlans::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SavingsPlans::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-savingsplans/client.rb
Overview
An API client for SavingsPlans. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::SavingsPlans::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_savings_plan(params = {}) ⇒ Types::CreateSavingsPlanResponse
Creates a Savings Plan.
-
#delete_queued_savings_plan(params = {}) ⇒ Struct
Deletes the queued purchase for the specified Savings Plan.
-
#describe_savings_plan_rates(params = {}) ⇒ Types::DescribeSavingsPlanRatesResponse
Describes the rates for a specific, existing Savings Plan.
-
#describe_savings_plans(params = {}) ⇒ Types::DescribeSavingsPlansResponse
Describes the specified Savings Plans.
-
#describe_savings_plans_offering_rates(params = {}) ⇒ Types::DescribeSavingsPlansOfferingRatesResponse
Describes the offering rates for Savings Plans you might want to purchase.
-
#describe_savings_plans_offerings(params = {}) ⇒ Types::DescribeSavingsPlansOfferingsResponse
Describes the offerings for the specified Savings Plans.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
-
#return_savings_plan(params = {}) ⇒ Types::ReturnSavingsPlanResponse
Returns the specified Savings Plan.
-
#tag_resource(params = {}) ⇒ Struct
Adds the specified tags to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the specified resource.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-savingsplans/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1040 1041 1042 |
# File 'lib/aws-sdk-savingsplans/client.rb', line 1040 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1043 1044 1045 |
# File 'lib/aws-sdk-savingsplans/client.rb', line 1043 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 |
# File 'lib/aws-sdk-savingsplans/client.rb', line 1013 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SavingsPlans') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-savingsplans' context[:gem_version] = '1.72.0' Seahorse::Client::Request.new(handlers, context) end |
#create_savings_plan(params = {}) ⇒ Types::CreateSavingsPlanResponse
Creates a Savings Plan.
533 534 535 536 |
# File 'lib/aws-sdk-savingsplans/client.rb', line 533 def create_savings_plan(params = {}, = {}) req = build_request(:create_savings_plan, params) req.send_request() end |
#delete_queued_savings_plan(params = {}) ⇒ Struct
Deletes the queued purchase for the specified Savings Plan.
555 556 557 558 |
# File 'lib/aws-sdk-savingsplans/client.rb', line 555 def delete_queued_savings_plan(params = {}, = {}) req = build_request(:delete_queued_savings_plan, params) req.send_request() end |
#describe_savings_plan_rates(params = {}) ⇒ Types::DescribeSavingsPlanRatesResponse
Describes the rates for a specific, existing Savings Plan.
616 617 618 619 |
# File 'lib/aws-sdk-savingsplans/client.rb', line 616 def describe_savings_plan_rates(params = {}, = {}) req = build_request(:describe_savings_plan_rates, params) req.send_request() end |
#describe_savings_plans(params = {}) ⇒ Types::DescribeSavingsPlansResponse
Describes the specified Savings Plans.
694 695 696 697 |
# File 'lib/aws-sdk-savingsplans/client.rb', line 694 def describe_savings_plans(params = {}, = {}) req = build_request(:describe_savings_plans, params) req.send_request() end |
#describe_savings_plans_offering_rates(params = {}) ⇒ Types::DescribeSavingsPlansOfferingRatesResponse
Describes the offering rates for Savings Plans you might want to purchase.
784 785 786 787 |
# File 'lib/aws-sdk-savingsplans/client.rb', line 784 def describe_savings_plans_offering_rates(params = {}, = {}) req = build_request(:describe_savings_plans_offering_rates, params) req.send_request() end |
#describe_savings_plans_offerings(params = {}) ⇒ Types::DescribeSavingsPlansOfferingsResponse
Describes the offerings for the specified Savings Plans.
884 885 886 887 |
# File 'lib/aws-sdk-savingsplans/client.rb', line 884 def describe_savings_plans_offerings(params = {}, = {}) req = build_request(:describe_savings_plans_offerings, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
913 914 915 916 |
# File 'lib/aws-sdk-savingsplans/client.rb', line 913 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#return_savings_plan(params = {}) ⇒ Types::ReturnSavingsPlanResponse
Returns the specified Savings Plan.
949 950 951 952 |
# File 'lib/aws-sdk-savingsplans/client.rb', line 949 def return_savings_plan(params = {}, = {}) req = build_request(:return_savings_plan, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds the specified tags to the specified resource.
978 979 980 981 |
# File 'lib/aws-sdk-savingsplans/client.rb', line 978 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the specified resource.
1004 1005 1006 1007 |
# File 'lib/aws-sdk-savingsplans/client.rb', line 1004 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1033 1034 1035 |
# File 'lib/aws-sdk-savingsplans/client.rb', line 1033 def waiter_names [] end |